<?php

namespace Drupal\alt_text_validation\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Alt Text Validation Setting form.
 */
class AltTextValidationSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'alt_text_validation_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['alt_text_validation.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form = parent::buildForm($form, $form_state);
    $form['#title'] = $this->t('Alt Text Validation Settings');
    $form['alt_text_validation_setting_group'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Validation status'),
    ];
    $form['alt_text_validation_setting_group']['alt_text_validation_setting'] = [
      '#prefix' => '<div class="container-inline">',
      '#type' => 'radios',
      '#options' => [
        'validation_on' => $this->t('On (all active rules applied)'),
        'validation_off' => $this->t('Off (no rules applied)'),
      ],
      '#default_value' => $this->config('alt_text_validation.settings')->get('alt_text_validation_setting'),
      '#suffix' => '</div>',
    ];
    $form['alt_text_validation_setting_group_alert headings'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Customize alert headings'),
    ];
    $form['alt_text_validation_setting_group_alert headings']['heading_warn'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Warn heading text'),
      '#default_value' => $this->config('alt_text_validation.settings')->get('heading_warn') ? $this->config('alt_text_validation.settings')->get('heading_warn') : $this->t('Alt text warnings, please consider addressing them.'),
    ];
    $form['alt_text_validation_setting_group_alert headings']['heading_prevent'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Prevent heading text'),
      '#default_value' => $this->config('alt_text_validation.settings')->get('heading_prevent') ? $this->config('alt_text_validation.settings')->get('heading_prevent') : $this->t('Alt text errors found. Page can not be saved.'),
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = $this->configFactory()->getEditable('alt_text_validation.settings');
    $config->set('alt_text_validation_setting', $form_state->getValue('alt_text_validation_setting'))
      ->set('heading_warn', $form_state->getValue('heading_warn'))
      ->set('heading_prevent', $form_state->getValue('heading_prevent'))
      ->save();
    parent::submitForm($form, $form_state);
  }

}
